using System;
using System.Drawing;
using System.Windows.Forms;
using Microsoft.StylusInput;
using Microsoft.StylusInput.PluginData;

namespace RTSCS
{
	public class CircleStylusLimited : IStylusSyncPlugin
	{
		private Control attachedControl;
		private Rectangle area;

		public CircleStylusLimited(Control control)
		{
			this.attachedControl = control;
			this.area = new Rectangle(50, 50, control.Width - 110, control.Height - 130);
		}

		public DataInterestMask DataInterest
		{
			get
			{
				return DataInterestMask.Packets | 
					DataInterestMask.StylusDown | 
					DataInterestMask.StylusUp;
			}
		}

		public void Packets(RealTimeStylus sender, 
			PacketsData data)
		{
			Graphics g = this.attachedControl.CreateGraphics();

			// We modify the Data
			this.ModifyData(data,g);

			int packetCounter;
			for (packetCounter = 0; 
				packetCounter <= (data.Count-data.PacketPropertyCount);
				packetCounter += data.PacketPropertyCount)
			{
				int iX; int iY;
				int iPressure = 10;
				iX = (int)(g.DpiX * data[packetCounter] / 2540);
				iY = (int)(g.DpiY * data[packetCounter + 1] / 2540);
				if (data.PacketPropertyCount > 2)
				{
					iPressure = data[packetCounter + 2] / 20;
				}
				g.DrawEllipse(Pens.Red, iX - iPressure, 
					iY - iPressure, iPressure * 2, iPressure * 2);
			}
		}

		public void ModifyData(PacketsData data, Graphics g)
		{
			int packetCounter;
			for (packetCounter = 0;
				packetCounter <= (data.Count - data.PacketPropertyCount);
				packetCounter += data.PacketPropertyCount)
			{
				int iX; int iY;

				// We map to screen space
				iX = (int)(g.DpiX * data[packetCounter] / 2540);
				iY = (int)(g.DpiY * data[packetCounter + 1] / 2540);
				
				// We verify that X and Y coordinates are withing the allowed rectangle
				iX = Math.Max(iX, this.area.Left);
				iX = Math.Min(iX, this.area.Right);
				iY = Math.Max(iY, this.area.Top);
				iY = Math.Min(iY, this.area.Bottom);

				// We map back to the digitizer space
				iX = (int)(iX * 2540 / g.DpiX);
				iY = (int)(iY * 2540 / g.DpiY);

				// We may have to change contained data 
				if (iX != data[packetCounter])
				{
					data[packetCounter] = iX;
				}
				if (iY != data[packetCounter + 1])
				{
					data[packetCounter + 1] = iY;
				}
			}
		}

		public void StylusDown(RealTimeStylus sender, 
			StylusDownData data)
		{
			Console.WriteLine("Stylus Down");
		}

		public void StylusUp(RealTimeStylus sender, 
			StylusUpData data)
		{
			Console.WriteLine("Stylus Up");
		}

		public void TabletRemoved(RealTimeStylus sender, 
			TabletRemovedData data)
		{}
		public void CustomStylusDataAdded(RealTimeStylus sender, 
			CustomStylusData data)
		{}
		public void RealTimeStylusDisabled(RealTimeStylus sender, 
			RealTimeStylusDisabledData data)
		{}
		public void StylusOutOfRange(RealTimeStylus sender, 
			StylusOutOfRangeData data)
		{}
		public void StylusButtonUp(RealTimeStylus sender, 
			StylusButtonUpData data)
		{}
		public void StylusInRange(RealTimeStylus sender, 
			StylusInRangeData data)
		{}
		public void RealTimeStylusEnabled(RealTimeStylus sender, 
			RealTimeStylusEnabledData data)
		{}
		public void SystemGesture(RealTimeStylus sender, 
			SystemGestureData data)
		{}
		public void TabletAdded(RealTimeStylus sender, 
			TabletAddedData data)
		{}
		public void Error(RealTimeStylus sender, 
			ErrorData data)
		{}
		public void InAirPackets(RealTimeStylus sender, 
			InAirPacketsData data)
		{}
		public void StylusButtonDown(RealTimeStylus sender, 
			StylusButtonDownData data)
		{}
	}
}
