using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using Microsoft.StylusInput;

namespace RTSCS
{
	/// <summary>
	/// Summary description for InkStylusAsyncForm.
	/// </summary>
	public class InkStylusAsyncForm : System.Windows.Forms.Form
	{
		private RealTimeStylus rts;
		private DynamicRenderer myDynamicRenderer;
		private Microsoft.Ink.Renderer myRenderer = new Microsoft.Ink.Renderer(); 
		private InkStylusAsync stylus;

		/// <summary>
		/// Required designer variable.
		/// </summary>
		private System.ComponentModel.Container components = null;

		public InkStylusAsyncForm()
		{
			//
			// Required for Windows Form Designer support
			//
			InitializeComponent();

			// We create the stylus
			this.rts = new RealTimeStylus(this);

			// We create the plug-in
			this.stylus = new InkStylusAsync(this, this.rts);
			this.rts.AsyncPluginCollection.Add(this.stylus);

			// We create a default dynamic renderer
			this.myDynamicRenderer = new DynamicRenderer(this);
			this.rts.SyncPluginCollection.Add(this.myDynamicRenderer);

			// We enable everything
			this.myDynamicRenderer.Enabled = true;
			this.rts.Enabled = true;
		}

		/// <summary>
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		protected override void OnPaint(PaintEventArgs e)
		{
			base.OnPaint (e);

			// Make sure the new ink is refreshed properly
			this.myDynamicRenderer.Refresh();

			// Render ink in the ink object
			this.myRenderer.Draw(e.Graphics, this.stylus.Ink.Strokes);
		}

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			this.components = new System.ComponentModel.Container();
			this.Size = new System.Drawing.Size(300,300);
			this.Text = "InkStylusAsyncForm";
		}
		#endregion
	}
}
