using System;
using System.Drawing;
using System.Windows.Forms;
using Microsoft.StylusInput;
using Microsoft.StylusInput.PluginData;

namespace RTSCS
{
	public class StylusData : IStylusSyncPlugin
	{
		private Control attachedControl;

		public StylusData(Control control)
		{
			this.attachedControl = control;
		}

		public DataInterestMask DataInterest
		{
			get
			{
				return DataInterestMask.Packets | 
					DataInterestMask.StylusDown | 
					DataInterestMask.StylusUp;
			}
		}

		public void Packets(RealTimeStylus sender, 
			PacketsData data)
		{
			Console.WriteLine("Number of Packets: " +
				data.Count.ToString());
			Console.WriteLine("Properties per packet: " + 
				data.PacketPropertyCount.ToString());

			Graphics g = this.attachedControl.CreateGraphics();

			int packetCounter;
			for (packetCounter = 0; 
				packetCounter <= (data.Count-data.PacketPropertyCount);
				packetCounter += data.PacketPropertyCount)
			{
				int iX; int iY;
				iX = (int)(g.DpiX * data[packetCounter] / 2540);
				iY = (int)(g.DpiY * data[packetCounter + 1] / 2540);

				Console.WriteLine("Packet: X "
					+ iX.ToString() + 
					"/ Y " + iY.ToString());
				if (data.PacketPropertyCount > 2)
				{
					Console.WriteLine("Pressure: " 
						+ data[packetCounter + 2].ToString());
					}
			}
		}

		public void StylusDown(RealTimeStylus sender, 
			StylusDownData data)
		{
			Console.WriteLine("Stylus Down");
		}

		public void StylusUp(RealTimeStylus sender, 
			StylusUpData data)
		{
			Console.WriteLine("Stylus Up");
		}

		public void TabletRemoved(RealTimeStylus sender, 
			TabletRemovedData data)
		{}
		public void CustomStylusDataAdded(RealTimeStylus sender, 
			CustomStylusData data)
		{}
		public void RealTimeStylusDisabled(RealTimeStylus sender, 
			RealTimeStylusDisabledData data)
		{}
		public void StylusOutOfRange(RealTimeStylus sender, 
			StylusOutOfRangeData data)
		{}
		public void StylusButtonUp(RealTimeStylus sender, 
			StylusButtonUpData data)
		{}
		public void StylusInRange(RealTimeStylus sender, 
			StylusInRangeData data)
		{}
		public void RealTimeStylusEnabled(RealTimeStylus sender, 
			RealTimeStylusEnabledData data)
		{}
		public void SystemGesture(RealTimeStylus sender, 
			SystemGestureData data)
		{}
		public void TabletAdded(RealTimeStylus sender, 
			TabletAddedData data)
		{}
		public void Error(RealTimeStylus sender, 
			ErrorData data)
		{}
		public void InAirPackets(RealTimeStylus sender, 
			InAirPacketsData data)
		{}
		public void StylusButtonDown(RealTimeStylus sender, 
			StylusButtonDownData data)
		{}
	}
}
