Imports Microsoft.StylusInput

Public Class CircleStylusLimited
    Implements IStylusSyncPlugin

    Public ReadOnly Property DataInterest() _
    As DataInterestMask _
    Implements IStylusSyncPlugin.DataInterest
        Get
            Return DataInterestMask.Packets _
                Or DataInterestMask.StylusDown _
                Or DataInterestMask.StylusUp
        End Get
    End Property

    Private attachedControl As Control
    Private area As Rectangle

    Public Sub New(ByVal control As Control)
        Me.attachedControl = control
        Me.area = New Rectangle(50, 50, control.Width - 110, control.Height - 130)
    End Sub

    Public Sub Packets(ByVal sender As RealTimeStylus, _
    ByVal data As PluginData.PacketsData) _
    Implements IStylusSyncPlugin.Packets
        Dim g As Graphics = Me.attachedControl.CreateGraphics()

        ' Check to make sure the data is in the valid range
        Me.ModifyData(data, g)

        ' Normal rendering
        Dim packetCounter As Integer
        For packetCounter = 0 To data.Count - data.PacketPropertyCount _
        Step data.PacketPropertyCount
            Dim iX As Integer
            Dim iY As Integer
            Dim iPressure As Integer = 10
            iX = g.DpiX * data(packetCounter) / 2540
            iY = g.DpiY * data(packetCounter + 1) / 2540
            If data.PacketPropertyCount > 2 Then
                iPressure = data(packetCounter + 2) / 20
            End If
            g.DrawEllipse(Pens.Red, iX - iPressure, iY - iPressure, iPressure * 2, iPressure * 2)
        Next
    End Sub

    Private Sub ModifyData(ByVal data As PluginData.PacketsData, ByVal g As Graphics)
        Dim packetCounter As Integer
        For packetCounter = 0 To data.Count - data.PacketPropertyCount _
        Step data.PacketPropertyCount
            Dim iX As Integer
            Dim iY As Integer

            ' We map to screen space
            iX = g.DpiX * data(packetCounter) / 2540
            iY = g.DpiY * data(packetCounter + 1) / 2540

            ' We verify that X and Y coordinates are withing the allowed rectangle
            iX = Math.Max(iX, Me.area.Left)
            iX = Math.Min(iX, Me.area.Right)
            iY = Math.Max(iY, Me.area.Top)
            iY = Math.Min(iY, Me.area.Bottom)

            ' We map back to the digitizer space
            iX = iX * 2540 / g.DpiX
            iY = iY * 2540 / g.DpiY

            ' We may have to change contained data 
            If iX <> data(packetCounter) Then
                data(packetCounter) = iX
            End If
            If iY <> data(packetCounter + 1) Then
                data(packetCounter + 1) = iY
            End If
        Next
    End Sub

    Public Sub StylusDown(ByVal sender As RealTimeStylus, _
    ByVal data As PluginData.StylusDownData) _
    Implements IStylusSyncPlugin.StylusDown
        Console.WriteLine("Stylus Down")
    End Sub

    Public Sub StylusUp(ByVal sender As RealTimeStylus, _
    ByVal data As PluginData.StylusUpData) _
    Implements IStylusSyncPlugin.StylusUp
        Console.WriteLine("Stylus Up")
    End Sub


    Public Sub CustomStylusDataAdded(ByVal sender As RealTimeStylus, ByVal data As PluginData.CustomStylusData) Implements IStylusSyncPlugin.CustomStylusDataAdded
    End Sub
    Public Sub [Error](ByVal sender As RealTimeStylus, ByVal data As PluginData.ErrorData) Implements IStylusSyncPlugin.Error
    End Sub
    Public Sub InAirPackets(ByVal sender As RealTimeStylus, ByVal data As PluginData.InAirPacketsData) Implements IStylusSyncPlugin.InAirPackets
    End Sub
    Public Sub RealTimeStylusDisabled(ByVal sender As RealTimeStylus, ByVal data As PluginData.RealTimeStylusDisabledData) Implements IStylusSyncPlugin.RealTimeStylusDisabled
    End Sub
    Public Sub RealTimeStylusEnabled(ByVal sender As RealTimeStylus, ByVal data As PluginData.RealTimeStylusEnabledData) Implements IStylusSyncPlugin.RealTimeStylusEnabled
    End Sub
    Public Sub StylusButtonDown(ByVal sender As RealTimeStylus, ByVal data As PluginData.StylusButtonDownData) Implements IStylusSyncPlugin.StylusButtonDown
    End Sub
    Public Sub StylusButtonUp(ByVal sender As RealTimeStylus, ByVal data As PluginData.StylusButtonUpData) Implements IStylusSyncPlugin.StylusButtonUp
    End Sub
    Public Sub StylusInRange(ByVal sender As RealTimeStylus, ByVal data As PluginData.StylusInRangeData) Implements IStylusSyncPlugin.StylusInRange
    End Sub
    Public Sub StylusOutOfRange(ByVal sender As RealTimeStylus, ByVal data As PluginData.StylusOutOfRangeData) Implements IStylusSyncPlugin.StylusOutOfRange
    End Sub
    Public Sub SystemGesture(ByVal sender As RealTimeStylus, ByVal data As PluginData.SystemGestureData) Implements IStylusSyncPlugin.SystemGesture
    End Sub
    Public Sub TabletAdded(ByVal sender As RealTimeStylus, ByVal data As PluginData.TabletAddedData) Implements IStylusSyncPlugin.TabletAdded
    End Sub
    Public Sub TabletRemoved(ByVal sender As RealTimeStylus, ByVal data As PluginData.TabletRemovedData) Implements IStylusSyncPlugin.TabletRemoved
    End Sub
End Class
